@@ -189,6 +189,8 @@ class Profile:
 		The equipped orb of the player.
 	orbs: `set`
 		The list of unlocked orbs.
+	isOnline: `bool`
+		Whether or not the player is online. See [#31](https://github.com/Athesdrake/aiotfm/pull/31#issuecomment-1537433271).
 	adventurePoints: `int`
 		Number of adventure points the player has.
 	"""
@@ -201,7 +203,7 @@ class Profile:
 		self.gender = packet.read8()
 		self.tribe = packet.readUTF() or None
 		self.soulmate = packet.readUTF() or None
-		stats = [packet.read32() for i in range(7)]
+		stats = [packet.read32() for i in range(10)]
 		self.title = packet.read16()
 
 		self.titles = set()
@@ -230,7 +232,7 @@ class Profile:
 		for _ in range(packet.read8()):
 			self.orbs.add(packet.read8())
 
-		packet.readBool()
+		self.isOnline = packet.readBool()
 		self.adventurePoints = packet.read32()
 
 
@@ -256,6 +258,12 @@ class Stats:
 	modeStats: `list`
 		A list of tuples that represents the stats in different mode.
 		(id, progress, progressLimit, imageId)
+	noSkillNormalModeSaves: `int`
+		Number of shaman saves in normal mode without skills.
+	noSkillHardModeSaves: `int`
+		Number of shaman saves in hard mode without skills.
+	noSkillDivineModeSaves: `int`
+		Number of shaman saves in divine mode without skills.
 	"""
 	def __init__(self, stats, modeStats):
 		self.normalModeSaves = stats[0]
@@ -265,5 +273,8 @@ class Stats:
 		self.firsts = stats[2]
 		self.gatheredCheese = stats[3]
 		self.bootcamps = stats[5]
+		self.noSkillNormalModeSaves = stats[7]
+		self.noSkillHardModeSaves = stats[8]
+		self.noSkillDivineModeSaves = stats[9]
 
 		self.modeStats = modeStats # id, progress, progressLimit, imageId
